function[sad,dum,tr]=ybandpass(s,samp,hiypc)
% BANDPASS creates a 52 sample per year bandpassed series "s".
% Output: sad=continuous, seasonally adjusted, noise 
%   reduced, differentiable, deviation from trend.; dum=a dummy
%   variable filler; tr = trend at original sample rate 
% Input: s= series at samp=samples per year, and hiypc = the
%   shortest period of interest in yeaars per cycle. 

pt=ftrend2k(s,samp,2,3);
note='entering ftrend2k, second time'
% plot(pt);title('pt out of firt pass through ftrend2k'); pause
[a,b,c,sad]=ftrend2k(pt,samp,hiypc,500); % ##wkw m-file #####

function[ptout,pt52,trend,shtrend52]=ftrend2k(s,samp,ypc,iter);
% FTREND2K uses spline function and fourier concepts to obtain
% trend and deviation from trend.
% to remove trend recommend ypc be one data series length --------------------
% to remove noise and seasonals from the resultant deviation series,
% recommend ypc =1.5.
% wkw January 2000
note='enter ftrend2k'
% REMOVE A STRAIGHT LINE AND AN ARC
% OUTPUTS are sampled weekly.
% INPUTS
% s=incoming series;samp=samples per year;ypc =max years per cycle in trend
% iter = max number of itererations if ypc is too small.
%
% series summed from low frequency (long cycles) to
% ypc (high freqency, short cycles) years per cycle.
%
% 01/07/00
% Walter K. Waymeyer, 5430 Sawmill Rd. #18, Paradise CA 95969
% waltkw@aol.com - (530) 877 9714
%
% If incoming s is a row, the next statement is unecessary ----------------
s=longrow(s); % assures longer rows than columns WKW m-file#########
%
% save original input series --------------------------------------------
save1=s;
[nsave1,msave1]=size(save1)
hold off;
% plot(s,'b');title('incoming series');hold on;grid;pause
%
% Find rms fitting straight line from input data --------------------------
% by any suitable method. Here it is done with a cubic SMOOTHING spline.
% ################################################
cs=csaps(1:msave1,save1,0.0); % #######spline m-file ###########
straight=fnval(cs,(1:msave1)); % ####spline m-file ##############
straight52=fnval(cs,(1:samp/52:msave1)); % weekly sampled straight
% ################################################
% could be done with a similar algorithm, the H-P filter with large argument.
% [pta,straight]=hpfilter(s,2000000);straight=straight';
%
% plot(straight);title('straight');pause
[nstraight,mstraight]=size(straight);
% plot(straight52(1:15));pause
[nstraight52,mstraight52]=size(straight52);
%
% subtract straight line from input data -- (put back later) ------------
s=s-straight;
%
% remove an arc from the series with straight line removed -------------
% ###############################################
[s,arc,arc52]=newarc(s,samp); % ##########################
% ###############################################
% hold off;plot(s,'c');title('s out of newarc, cobalt');pause
% remove mean from s
means=mean(s)*ones(1,msave1);
means52=means(1:samp/52:msave1); % weekly sampled mean --------
[nmeans,mmeans]=size(means);
s=s-means;
% plot(s,'r');title('input with straight arc, and mean removed');pause
% save input series with straight line, arc, and mean removed ---------
save2=s;
% plot(save2);title('input series with straight removed');
%
% Extend series in each direction, mirroring about the end points. --------
% May be worth experimenting with other extensions, series dependent --
% Choice affects the convergence at the ends of the series --------------
s=[fliplr(s) s fliplr(s) ];
% hold off;plot(s,'w');title('extended series w/o straight and arc');pause
save3=s;
[ns,ms]=size(s);
% compute years per cycle of Fourier component ---------------------
years=ms/samp
% Examine following graph to assess the "fliplr" extensions ------------&&
% plot(s,'m');title('straight removed, extended by mirroring');pause
% initialize trend before entering loop-----------------------------------
trend=zeros(1,ms);
trend52=0*(1:samp/52:ms);
[ntrend52,mtrend52]=size(trend52);
% begin loop ------------------------------------!!!!!!!!!!!!!!!!!!!!!!!!!
% find fourier components one by one, lowest frequency first --------
% loop terminates when ypcycle is less than ypc (input argument) ----
% or when i = iter (input argument) -------------------------------
%
for i=1:iter
% compute years per cycle of current pass -------------------------
ypcycle=1*(ms/samp)/(i)
ypco(i)=ypcycle;
% "if" below regulates output plots ------------!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
if ypco(i)>14
ypco(i) = 14;
end
% end of regulate output frequency response plots !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
freq(i)=1/ypcycle;
% fcyclek finds the ith component of extended series with "straight" removed
% #####################################################
[tri,total,tri52]=fcyclek(save3,i,samp); % #########WKW m-file #########
% #####################################################
% plot(tri,'c');title('tri returned from fcyclek, cobalt');
[ntri,mtri]=size(tri);
[ntri52,mtri52]=size(tri52);
% plot(tri52,'c');title('tri52 returned from fcyclek, cobalt');
% collect amplitude of Fourier component for plots ------------------------
amp(i)=total;
% add new component to trend ------------------------------------------
tri=trend+tri;
tri52=trend52+tri52;
% determine current deviation from trend -------------------------------
pti=save3-tri;
% identify new current trend for next pass ------------------------------
trend=tri;
trend52=tri52;
% To watch the trend develop, and absorb higher frequencies, enable next two plots.
% plot(save3(ms/3+1:2/3*ms));hold on
% plot(save3(1:samp/52:ms),'y');title('saved extended series, straight removed');hold on
% plot(tri52,'r');title('extended trend, red');pause
[ntri52,mtri52]=size(tri52);
% plot(trend,'r');title('trend, red');grid;hold on;pause
meanpti=mean(pti);
rmspti=sqrt(pti*pti'/ms);
if ypcycle<ypc, break, end
end; % end loop ---------------------------------!!!!!!!!!!!!!!!!!!!!!!!!!
% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% for extended series:
% plot amplitude vs. frequency in cycles per year or
% plot amplitude vs. period in years per cycle
hold off
% plot(freq,amp,'w');title('periodogram, cpy');pause
plot(ypco(1:i-1),amp(1:i-1),'w');title('periodogram, ypc');grid;pause
hold off;
% find autocorrelation function -----------------------------------------
% of original length series trend and deviation from trend -----------------
autopti=autocorr(pti(ms/3+1:2/3*ms)); % ##WKW m-file ###########
autotri=autocorr(tri(ms/3+1:2/3*ms)); % ##WKW m-file ###########
lengthautopti=length(autopti);
% To assess the frequency content of the trend and the deviation,
% via autocorrelation function enable the next two plots.
% plot((0:lengthautopti-1),autotri,'w');hold on;
% plot((0:lengthautopti-1),autopti,'w-.');title('Fourier filter - normal autocorrelation trend ,solid - deviation, dash/dot');
% remove series extensions replace straight------------------------------
hold off
[ntri,mtri]=size(tri(ms/3+1:2/3*ms));
[nstraight,mstraight]=size(straight);
trend=tri(ms/3+1:2/3*ms)+straight+arc+means;
deviation=save1-trend;
% plot(deviation,'c');title('deviation');pause;hold on
% plot(trend,'w');title('trend, white');pause;grid;hold on
% plot(save1,'r');title('input series,red');pause
% select the original (center) series parts
note='compare sizes';
[naa,maa]=size(tri52(mtri52/3+1:2/3*mtri52));
[ntri52s,mtri52s]=size(tri52(mtri52/3+1:2/3*mtri52));
tri52s=(tri52(mtri52/3+1:2/3*mtri52));
tri52s=tri52s(1:mstraight52);
[ntri52s,mtri52s]=size(tri52s);
shtrend52=zeros(1,mstraight52);
[nshtrend52,mshtrend52]=size(shtrend52);
shtrend52=tri52s+ straight52+arc52+means52;
% hold off;plot(tri52(1:25));hold on;title('tri52');pause
% hold off;plot(straight52(1:25));hold on;title('straight52');pause
% hold off;plot(arc52(1:25));hold on;title('arc52');pause
% hold off;plot(means52(1:25));hold on;title('means52');pause
[nshtrend52,mshtrend52]=size(shtrend52);
% plot(shtrend52(1:mshtrend52),'c');title('shtrend5,cobalt');pause;hold on
% plot(shtrend52,'c');title('shtrend5,cobalt');pause;hold on
% plot(shtrend52(1:samp/52:ms/3),'w');title('shtrend, solid line');hold on;
% plot(shtrend52,'w');title('shtrend52, solid line');hold on;pause
% plot(pti(ms/3+1:samp/52:2/3*ms),'w-.');title('pti,dash dot');pause
ptout=pti(ms/3+1:2/3*ms);
% rmspt=ptout*ptout'/ms/3
[nsave1,msave1]=size(save1);
[nsave1p,msave1p]=size(save1(1:samp/52:msave1));
[nstraight52,mstraight52]=size(straight52);
save52=save1(1:samp/52:msave1);
% plot(save1(1:samp/52:msave1),'w:');title('save 52,white');pause
save52=save52(1:mstraight52);
[nsave52,msave52]=size(save52);
[nshtrend52,mshtrend52]=size(shtrend52);
[nstraight52,mstraight52]=size(straight52);
pt52=save52-shtrend52-1*straight52-1*arc52;
% plot(-pt52,'g-.');title('pt52 out of ftrendk, green');pause
% title('Fourier filter: input,dots - shtrend,solid - deviation,dash/dot');pause
note='leave ftrend2k'
